@@ -347,8 +347,13 @@ setClassUnion("SolutionORList", c("Solution", "list"))
 #' @name Problem-class
 #' @aliases Problem
 #' @rdname Problem-class
-.Problem <- setClass("Problem", representation(objective = "Objective", constraints = "list", variables = "list", value = "numeric", status = "character", solution = "ANY", .intermediate_chain = "ANY", .solving_chain = "ANY", .cached_chain_key = "list", .separable_problems = "list", .size_metrics = "SizeMetricsORNULL", .solver_stats = "list", args = "list", .solver_cache = "list", .intermediate_problem = "ANY", .intermediate_inverse_data = "ANY"),
-                    prototype(constraints = list(), value = NA_real_, status = NA_character_, solution = NULL, .intermediate_chain = NULL, .solving_chain = NULL, .cached_chain_key = list(), .separable_problems = list(), .size_metrics = NULL, .solver_stats = NULL, args = list(), .solver_cache = list(), .intermediate_problem = NULL, .intermediate_inverse_data = NULL),
+.Problem <- setClass("Problem", representation(objective = "Objective", constraints = "list", variables = "list", value = "numeric", status = "character", solution = "ANY", .intermediate_chain = "ANY", .solving_chain = "ANY", .cached_chain_key = "list", .separable_problems = "list", .size_metrics = "SizeMetricsORNULL", .solver_stats = "list", args = "list", .solver_cache = "environment", .intermediate_problem = "ANY", .intermediate_inverse_data = "ANY"),
+                    prototype(constraints = list(), value = NA_real_, status = NA_character_, solution = NULL, .intermediate_chain = NULL, .solving_chain = NULL, .cached_chain_key = list(), .separable_problems = list(), .size_metrics = NULL, .solver_stats = NULL, args = list(), .solver_cache = new.env(parent=emptyenv()), .intermediate_problem = NULL, .intermediate_inverse_data = NULL),
+                    ## CLEANUP NOTE: The prototype should probably be
+                    ## removed in future versions since we never use
+                    ## it In particular, initializing the solver_cache
+                    ## environment at argument level poses problems in
+                    ## R 3.6 at least
                     validity = function(object) {
                       if(!(class(object@objective) %in% c("Minimize", "Maximize")))
                         stop("[Problem: objective] objective must be Minimize or Maximize")
@@ -392,7 +397,7 @@ Problem <- function(objective, constraints = list()) {
 # Used by pool.map to send solve result back. Unsure if this is necessary for multithreaded operation in R.
 SolveResult <- function(opt_value, status, primal_values, dual_values) { list(opt_value = opt_value, status = status, primal_values = primal_values, dual_values = dual_values, class = "SolveResult") }
 
-setMethod("initialize", "Problem", function(.Object, ..., objective, constraints = list(), variables, value = NA_real_, status = NA_character_, solution = NULL, .intermediate_chain = NULL, .solving_chain = NULL, .cached_chain_key = list(), .separable_problems = list(), .size_metrics = SizeMetrics(), .solver_stats = list(), args = list(), .solver_cache = list(), .intermediate_problem = NULL, .intermediate_inverse_data = NULL) {
+setMethod("initialize", "Problem", function(.Object, ..., objective, constraints = list(), variables, value = NA_real_, status = NA_character_, solution = NULL, .intermediate_chain = NULL, .solving_chain = NULL, .cached_chain_key = list(), .separable_problems = list(), .size_metrics = SizeMetrics(), .solver_stats = list(), args = list(), .solver_cache, .intermediate_problem = NULL, .intermediate_inverse_data = NULL) {
   .Object@objective <- objective
   .Object@constraints <- constraints
   .Object@variables <- Problem.build_variables(.Object)
@@ -419,7 +424,7 @@ setMethod("initialize", "Problem", function(.Object, ..., objective, constraints
   .Object@args <- list(.Object@objective, .Object@constraints)
 
   # Cache for warm start.
-  .Object@.solver_cache <- list()
+  .Object@.solver_cache <- new.env(parent=emptyenv())
   .Object
 })
 
@@ -659,7 +664,7 @@ setMethod("get_problem_data", signature(object = "Problem", solver = "character"
 #' @docType methods
 #' @rdname psolve
 #' @export
-setMethod("psolve", "Problem", function(object, solver = NA, ignore_dcp = FALSE, warm_start = FALSE, verbose = FALSE, 
+setMethod("psolve", "Problem", function(object, solver = NA, ignore_dcp = FALSE, warm_start = FALSE, verbose = FALSE,
                                         parallel = FALSE, gp = FALSE, feastol = NULL, reltol = NULL, abstol = NULL, num_iter = NULL,  ...) {
   if(parallel)
     stop("Unimplemented")
@@ -668,7 +673,7 @@ setMethod("psolve", "Problem", function(object, solver = NA, ignore_dcp = FALSE,
   object@.solving_chain <- tmp[[1]]
   data <- tmp[[2]]
   solving_inverse_data <- tmp[[3]]
-  solution <- reduction_solve_via_data(object@.solving_chain, object, data, warm_start, 
+  solution <- reduction_solve_via_data(object@.solving_chain, object, data, warm_start,
                                        verbose, feastol, reltol, abstol, num_iter, list(...))
 
   full_chain <- prepend(object@.solving_chain, object@.intermediate_chain)
